@@ -1,4 +1,4 @@
-# $Id: ODBC.pm 14890 2011-06-22 19:33:10Z mjevans $
+# $Id: ODBC.pm 15016 2011-11-24 09:26:38Z mjevans $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
 # portions Copyright (c) 1997-2004  Jeff Urlwin
@@ -19,7 +19,7 @@ require 5.008;
 # see discussion on dbi-users at
 # http://www.nntp.perl.org/group/perl.dbi.dev/2010/07/msg6096.html and
 # http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-$DBD::ODBC::VERSION = '1.31';
+$DBD::ODBC::VERSION = '1.33';
 
 {
     ## no critic (ProhibitMagicNumbers ProhibitExplicitISA)
@@ -32,7 +32,7 @@ $DBD::ODBC::VERSION = '1.31';
 
     @ISA = qw(Exporter DynaLoader);
 
-    # my $Revision = substr(q$Id: ODBC.pm 14890 2011-06-22 19:33:10Z mjevans $, 13,2);
+    # my $Revision = substr(q$Id: ODBC.pm 15016 2011-11-24 09:26:38Z mjevans $, 13,2);
 
     require_version DBI 1.21;
 
@@ -147,7 +147,8 @@ $DBD::ODBC::VERSION = '1.31';
             odbc_err_handler               => undef,
             odbc_putdata_start             => undef, # sth and dbh
             odbc_column_display_size       => undef, # sth and dbh
-            odbc_utf8_on                   => undef # sth and dbh
+            odbc_utf8_on                   => undef, # sth and dbh
+	    odbc_driver_complete           => undef
                };
     }
 
@@ -567,7 +568,7 @@ DBD::ODBC - ODBC Driver for DBI
 
 =head1 VERSION
 
-This documentation refers to DBD::ODBC version 1.31.
+This documentation refers to DBD::ODBC version 1.33.
 
 =head1 SYNOPSIS
 
@@ -1163,6 +1164,38 @@ now 3.x, this can be used to force 2.x behavior via something like: my
   $dbh = DBI->connect("dbi:ODBC:$DSN", $user, $pass,
                       { odbc_version =>2});
 
+=head3 odbc_driver_complete
+
+This attribute was added to DBD::ODBC in 1.32_2.
+
+odbc_driver_complete is only relevant to the Windows operating system
+and will be ignored on other platforms. It is off by default.
+
+When set to a true value DBD::ODBC attempts to obtain a window handle
+and calls SQLDriverConnect with the SQL_DRIVER_COMPLETE attribute
+instead of the normal SQL_DRIVER_NOPROMPT option. What this means is
+that if the connection string does not describe sufficient attributes
+to enable the ODBC driver manager to connect to a data source it will
+throw a dialogue allowing you to input the remaining attributes. Once
+you ok that dialogue the ODBC Driver Manager will continue as if you
+specified those attributes in the connection string. Once the
+connection is complete you may want to look at the odbc_out_connect_string
+attribute to obtain a connection string you can use in the future to
+pass into the connect method without prompting.
+
+As a window handle is passed to SQLDriverConnect it also means the
+ODBC driver may throw a dialogue e.g., if your password has expired
+the MS SQL Server driver will often prompt for a new one.
+
+An example is:
+
+  my $h = DBI->connect('dbi:ODBC:DRIVER={SQL Server}', "username", "password",
+                       {odbc_driver_complete => 1});
+
+As this only provides the driver and further attributes are required a
+dialogue will be thrown allowing you to specify the SQL Server to
+connect to and possibly other attributes.
+
 =head2 Private statement methods
 
 =head3 odbc_lob_read
@@ -1776,6 +1809,12 @@ You cannot use unicode parameter names e.g.,
 You cannot use unicode strings in calls to prepare if you set the
 odbc_execdirect attribute.
 
+You cannot pass unicode catalog, schema, table and column names into
+metadata calls (like column_info) at present because the XS interface
+uses char * instead of Perl scalars. NOTE: as of DBD::ODBC 1.32_3 Unicode
+is fully supported for input parameters in table_info. As of DBD::ODBC
+1.32_5 Unicode is fully supported for input parameters in column_info.
+
 You cannot use the iODBC driver manager with DBD::ODBC built for
 unicode.
 
